{% if not nav_item.children %}
<li {% if nav_item.active %}class="active"{% endif %}>
    <a href="{{ nav_item.url|url }}">{{ nav_item.title }}</a>
</li>
{% else %}
  <li class="dropdown-submenu">
    <a tabindex="-1" href="">{{ nav_item.title }}</a>
    <ul class="dropdown-menu">
        {% for nav_item in nav_item.children %}
            {% include "nav-sub.html" %}
        {% endfor %}
    </ul>
  </li>
{% endif %}
